@@ -26,6 +26,7 @@ from .MultiCommand import MultiCommand
 from .ActionRender import ActionRender
 from .ActionServe import ActionServe
 from .ActionAcroAdd import ActionAcroAdd
+from .ActionAcroScan import ActionAcroScan
 from .ActionAcroSort import ActionAcroSort
 from .ActionPurge import ActionPurge
 from .ActionHashPresentation import ActionHashPresentation
@@ -33,7 +34,9 @@ from .ActionDumpMetadata import ActionDumpMetadata
 from .ActionSpellcheck import ActionSpellcheck
 from .ActionDictAdd import ActionDictAdd
 from .ActionShowStyleOpts import ActionShowStyleOpts
+from .ActionTemplateHelper import ActionTemplateHelper
 from .Enums import PresentationFeature
+from .GlobalConfig import GlobalConfig
 
 def _geometry(text):
 	text = text.split("x", maxsplit = 1)
@@ -48,6 +51,7 @@ def _resource_dir(text):
 	return (text[0], text[1])
 
 def main():
+	gc = GlobalConfig.read()
 	mc = MultiCommand(description = "HTML presentation renderer", trailing_text = "version: pyradium v%s" % (pyradium.VERSION))
 
 	def genparser(parser):
@@ -90,6 +94,12 @@ def main():
 		parser.add_argument("acrofile", help = "Acronym database JSON file.")
 	mc.register("acroadd", "Add an acryonym to the acronym database", genparser, action = ActionAcroAdd, aliases = [ "aadd" ])
 
+	def genparser(parser):
+		parser.add_argument("-v", "--verbose", action = "count", default = 0, help = "Increases verbosity. Can be specified multiple times to increase.")
+		parser.add_argument("acrofile", help = "Acronym database JSON file.")
+		parser.add_argument("infile", help = "Input XML file of the presentation.")
+	mc.register("acroscan", "Scans a presentation and suggests acronyms that can be added", genparser, action = ActionAcroScan, aliases = [ "ascan" ])
+
 	def genparser(parser):
 		parser.add_argument("-v", "--verbose", action = "count", default = 0, help = "Increases verbosity. Can be specified multiple times to increase.")
 		parser.add_argument("acrofile", help = "Acronym database JSON file.")
@@ -114,11 +124,12 @@ def main():
 	mc.register("dumpmeta", "Dump the metadata dictionary in JSON format", genparser, action = ActionDumpMetadata)
 
 	def genparser(parser):
-		group = parser.add_mutually_exclusive_group(required = True)
-		group.add_argument("-u", "--uri", metavar = "uri", help = "Connect to this running LanguageTool server URI.")
-		group.add_argument("-j", "--jar", metavar = "jarfile", help = "Start a LanguageTool server using this languagetool-server.jar JAR, automatically connect to it and shut it down after use.")
+		have_default_spellchecker = gc.has("spellcheck", "uri") or gc.has("spellcheck", "jar")
+		group = parser.add_mutually_exclusive_group(required = not have_default_spellchecker)
+		group.add_argument("-u", "--uri", metavar = "uri", default = gc.get("spellcheck", "uri"), help = "Connect to this running LanguageTool server URI.")
+		group.add_argument("-j", "--jar", metavar = "jarfile", default = gc.get("spellcheck", "jar"), help = "Start a LanguageTool server using this languagetool-server.jar JAR, automatically connect to it and shut it down after use.")
 		parser.add_argument("-l", "--language", metavar = "lang", default = "en-US", help = "Spellcheck in this language. Defaults to %(default)s.")
-		parser.add_argument("-m", "--mode", choices = [ "print", "vim", "evim", "fulljson" ], default = "print", help = "Mode in which spellchecking is performed. Can be one of %(choices)s, defaults to %(default)s.")
+		parser.add_argument("-m", "--mode", choices = [ "print", "vim", "evim", "fulljson" ], default = gc.get("spellcheck", "mode") or "print", help = "Mode in which spellchecking is performed. Can be one of %(choices)s, defaults to %(default)s.")
 		parser.add_argument("-o", "--outfile", metavar = "filename", help = "Write output to this file. By default, outputs to stdout.")
 		parser.add_argument("--vim", action = "store_true", help = "Run vim to actually spellcheck the file in question.")
 		parser.add_argument("-f", "--force", action = "store_true", help = "Overwrite files in destination directory if they already exist.")
@@ -131,6 +142,11 @@ def main():
 		parser.add_argument("infile", help = "Input file, needs to be a quickfix file in evim format.")
 	mc.register("dictadd", "Add false-positive spellcheck errors to the dictionary", genparser, action = ActionDictAdd)
 
+	def genparser(parser):
+		parser.add_argument("-v", "--verbose", action = "count", default = 0, help = "Increases verbosity. Can be specified multiple times to increase.")
+		parser.add_argument("template_name", help = "Name of the template to insert.")
+	mc.register("template-helper", "Show different templates on stdout; used in conjunction with vim plugins", genparser, action = ActionTemplateHelper)
+
 	return mc.run(sys.argv[1:])
 
 if __name__ == "__main__":
