@@ -19,12 +19,15 @@
 #
 #	Johannes Bauer <JohannesBauer@gmx.de>
 
+import logging
 from pyradium.xmlhooks.XMLHookRegistry import BaseHook, XMLHookRegistry
 
+_log = logging.getLogger(__spec__.name)
+
 @XMLHookRegistry.register_hook
 class DebugHook(BaseHook):
 	_TAG_NAME = "debug"
 
 	@classmethod
 	def handle(cls, rendered_presentation, node):
-		print("Debug hook:", node)
+		_log.debug("Debug hook: %s", str(node))
